This is a placeholder changelog file, will we replaced before the 2.0 stable.

Draft notes
===========

listener collections

event names are now strings, always (for performance reasons)
priorities are more strict, and mapped to strings in fine (for preformance reasons)

interface prototypes are more strict with positional/keyword arguments to avoid ambiguity

added protocols


Changelog since 1.x
===================

* fix: read the docs (Romain Dorgueil)
* fix: test runner using poetry (Romain Dorgueil)
* Update and rename .readthedocs.yml to .readthedocs.yaml (Romain Dorgueil)
* fix: read the docs (Romain Dorgueil)
* feat: readthedocs config (Romain Dorgueil)
* chore: upgrade dependencies (Romain Dorgueil)
* feat: bump version (Romain Dorgueil)
* chore: cosmetics (Romain Dorgueil)
* feat: add listeners collection management methods to IAbstractEventDispatcher (Romain Dorgueil)
* fix: async event dispatcher interface (Romain Dorgueil)
* feat: refactoring, clear sync/async interface, better typing, tests (Romain Dorgueil)
* feat: root level interfaces (Romain Dorgueil)
* misc: add internal roadmap to ignores (Romain Dorgueil)
* feat: start working on async dispatcher and protocols (Romain Dorgueil)
* Update requirements. (Romain Dorgueil)
* Update requirements. (Romain Dorgueil)
* Update requirements / format. (Romain Dorgueil)
* Update project assets & requirements. (Romain Dorgueil)
* Update travis to use pypy3. (Romain Dorgueil)
